rulebase.rules.interval\_based\_operations.interval\_based\_collector module
============================================================================

.. automodule:: rulebase.rules.interval_based_operations.interval_based_collector
    :members:
    :undoc-members:
    :show-inheritance:
